==> kendo-charts-vue-wrapper-2022.1.119.tgz: package/docs/series-types/donut.md <==
---
title: Donut
page_title: Donut Series Type - Chart - Kendo UI for Vue
description: "Basic usage of the Kendo UI Donut Charts in Vue projects."
slug: donut_seriestypes_charts
canonicalLink: "https://www.telerik.com/kendo-vue-ui/components/charts/donut/"
---

<WrapperBanner link="/kendo-vue-ui/components/charts/donut"></WrapperBanner>

# Donut

Donut charts are circular charts which represent a variation of the [Pie charts]({% slug pie_seriestypes_charts %}) and are capable of displaying multiple nested series.

You can use them as a replacement for dashboard gauges and meters. The bullet graph compares a given quantitative measure, such as temperature, against a qualitative range, such as warm, hot, and cold, and a symbol marker which encodes the comparative measure, such as the max temperature a year ago.

## Basic Usage

The following example demonstrates the Donut chart in action.

{% meta height:460 %}
{% embed_file series-types/donut/basic-usage/main.vue preview %}
{% embed_file series-types/donut/basic-usage/main.js %}
{% endmeta %}

## Donut Labels

The Donut chart labels allow two types of alignment&mdash;`column` or `circle`. The column alignment justifies the labels to the two sides of the Chart while the circle alignment positions the labels in a circle around the Chart.

{% meta height:580 %}
{% embed_file series-types/donut/labels/main.vue preview %}
{% embed_file series-types/donut/labels/main.js %}
{% endmeta %}

## Suggested Links

* [Kendo UI Chart for jQuery](https://docs.telerik.com/kendo-ui/controls/charts/overview)
* [API Reference of the Chart Widget](https://docs.telerik.com/kendo-ui/api/javascript/dataviz/ui/chart)

==> kendo-charts-vue-wrapper-2022.3.1109.tgz: package/docs/series-types/donut.md <==
---
title: Donut
page_title: Donut Series Type - Chart - Kendo UI for Vue
description: "Basic usage of the Kendo UI Donut Charts in Vue projects."
slug: donut_seriestypes_charts_wrapper
canonicalLink: "https://www.telerik.com/kendo-vue-ui/components/charts/donut/"
---

<WrapperBanner link="/kendo-vue-ui/components/charts/donut"></WrapperBanner>

# Donut

Donut charts are circular charts which represent a variation of the [Pie charts]({% slug pie_seriestypes_charts_wrapper %}) and are capable of displaying multiple nested series.

You can use them as a replacement for dashboard gauges and meters. The bullet graph compares a given quantitative measure, such as temperature, against a qualitative range, such as warm, hot, and cold, and a symbol marker which encodes the comparative measure, such as the max temperature a year ago.

## Basic Usage

The following example demonstrates the Donut chart in action.

{% meta height:460 %}
{% embed_file series-types/donut/basic-usage/main.vue preview %}
{% embed_file series-types/donut/basic-usage/main.js %}
{% endmeta %}

## Donut Labels

The Donut chart labels allow two types of alignment&mdash;`column` or `circle`. The column alignment justifies the labels to the two sides of the Chart while the circle alignment positions the labels in a circle around the Chart.

{% meta height:580 %}
{% embed_file series-types/donut/labels/main.vue preview %}
{% embed_file series-types/donut/labels/main.js %}
{% endmeta %}

## Suggested Links

* [Kendo UI Chart for jQuery](https://docs.telerik.com/kendo-ui/controls/charts/overview)
* [API Reference of the Chart Widget](https://docs.telerik.com/kendo-ui/api/javascript/dataviz/ui/chart)
